@@ -1,14 +1,14 @@
 package Data::Sah::CoerceJS;
 
 our $DATE = '2016-05-17'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict 'subs', 'vars';
 use warnings;
 use Log::Any::IfLOG '$log';
 
-use Data::Sah::Util::JS qw(get_nodejs_path);
+use Nodejs::Util qw(get_nodejs_path);
 
 use Exporter qw(import);
 our @EXPORT_OK = qw(gen_coercer);
@@ -172,7 +172,7 @@ Data::Sah::CoerceJS - Generate Perl code to execute JavaScript coercer
 
 =head1 VERSION
 
-This document describes version 0.002 of Data::Sah::CoerceJS (from Perl distribution Data-Sah-Coerce), released on 2016-05-17.
+This document describes version 0.003 of Data::Sah::CoerceJS (from Perl distribution Data-Sah-Coerce), released on 2016-05-17.
 
 =head1 SYNOPSIS
 
